@@ -1,17 +1,17 @@
 from __future__ import annotations
 
+from copy import deepcopy
 import sys
 import warnings
 from typing import Optional, Tuple, Union
 from pathlib import Path
 
-import matplotlib as mpl
 import numpy as np
 import pandas as pd
 from libpysal.weights import KNN
 from libpysal.weights import W as libpysal_W
 
-from . import cluster, density, moran, plot
+from . import cluster, density, moran
 
 DataFrames = Union[pd.DataFrame, np.ndarray, Path, str]
 if not sys.warnoptions:
@@ -77,7 +77,7 @@ class STDataset(object):
 
         # dataframes check
         if isinstance(count_df, pd.DataFrame):
-            self._count_df = count_df
+            self._count_df = deepcopy(count_df)
         elif isinstance(count_df, np.ndarray):
             self._count_df = pd.DataFrame(count_df)
         else:
@@ -86,7 +86,7 @@ class STDataset(object):
             self._count_df = self._count_df.T
 
         if isinstance(coordinate_df, pd.DataFrame):
-            self._coordinate_df = coordinate_df
+            self._coordinate_df = deepcopy(coordinate_df)
         elif isinstance(coordinate_df, np.ndarray):
             self._coordinate_df = pd.DataFrame(coordinate_df)
         else:
@@ -107,17 +107,31 @@ class STDataset(object):
         assert all(self._count_df.index == self._coordinate_df.index), err
 
         # Rename duplicated columns
-        cols = pd.Series(self._count_df.columns)
-        dups = self._count_df.columns[self._count_df.columns.duplicated(
-            keep=False)]
-        for dup in dups:
-            cols[self._count_df.columns.get_loc(dup)] = ([
-                dup + '.' + str(d_idx) if d_idx != 0 else dup
-                for d_idx in range(self._count_df.columns.get_loc(dup).sum())
-            ])
-        if len(dups) > 0:
+        genes = []
+        flag = 0
+        for gene_name in self._count_df.columns:
+            while 1:
+                if gene_name in genes:
+                    gene_name += "*"
+                    flag += 1
+                else:
+                    break
+            genes.append(gene_name)
+        if flag:
+            self._count_df.columns = genes
             warnings.warn("Duplicated column names found. Auto rename.")
-            self._count_df.columns = cols
+
+    def __del__(self) -> None:
+        del self._count_df
+        del self._coordinate_df
+        del self._hotspot_df
+        del self._weight
+        del self._weight_type
+        del self._local_moran_i
+        del self._local_moran_p
+        del self._AI
+        del self._Di
+        del self._svg_cluster
 
     def acquire_weight(self, k: int = 6, **kwargs) -> None:
         """
@@ -125,7 +139,7 @@ class STDataset(object):
 
         Parameters
         ==========
-        k: int, default 6
+        k : int, default 6
             Number of nearest neighbors for KNN network.
 
         **kwargs
@@ -165,7 +179,7 @@ class STDataset(object):
 
         Parameters
         ==========
-        cores: int
+        cores : int
             Number of threads to run svgbit. Use all available cpus by default.
 
         """
@@ -188,10 +202,10 @@ class STDataset(object):
 
         Parameters
         ==========
-        n_svgs: int, default 1000
+        n_svgs : int, default 1000
             Number of SVGs to find clusters.
 
-        n_svg_clusters: int, default 8
+        n_svg_clusters : int, default 8
             Number of SVG clusters to find.
 
         """
@@ -202,31 +216,6 @@ class STDataset(object):
             n_svg_clusters=n_svg_clusters,
         )
 
-    def svg_heatmap(
-        self,
-        save_path: Union[str, Path],
-        he_image=None,
-    ) -> Tuple[mpl.figure.Figure, np.ndarray[mpl.axes.Axes]]:
-        """
-        Draw SVG distribution heatmap.
-
-        Patameters
-        ==========
-        save_path: str or pathlib.Path
-            Heatmap save path.
-
-        he_image: PIL.Image.Image, default None
-            H&E image of tissue. If None is given (default), distribution map
-            will not show tissue picture.
-        """
-        plot.svg_heatmap(
-            self._hotspot_df,
-            self._coordinate_df,
-            self._svg_cluster,
-            save_path,
-            he_image,
-        )
-
     @property
     def count_df(self) -> pd.DataFrame:
         """Expression matrix."""
